@@ -478,7 +478,9 @@ probably isn't what you meant.""" %
 		assert include == 0 or include == 1
 
 		def sel_func(rp):
-			if rp.isdir() and rp.readable() and rp.append(presence_filename).isreg(): return include
+			if rp.isdir() and rp.readable() and \
+					rp.append(presence_filename).lstat():
+				return include
 			return None
 
 		sel_func.exclude = not include
@@ -529,8 +531,10 @@ probably isn't what you meant.""" %
 		"""Return selection function given by filesize"""
 		size = int(sizestr)
 		assert size > 0
-		if min_max: sel_func = lambda rp: (rp.getsize() <= size)
-		else: sel_func = lambda rp: (rp.getsize() >= size)
+		def sel_func(rp):
+			if not rp.isreg(): return None
+			if min_max: return ((rp.getsize() <= size) and None)
+			else: return ((rp.getsize() >= size) and None)
 		sel_func.exclude = 1
 		sel_func.name = "%s size %d" % (min_max and "Maximum" or "Minimum", size)
 		return sel_func
